/* ****************************************************************************
 * Copyright (c) 2002 Java Eclipse Extension Project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.opensource.org/licenses/cpl.php
 * ============================================================================
 * $Header: /cvsroot/jeextension/jp.sourceforge.jeextension.styleeditor/src/jp/sourceforge/jeextension/styleeditor/preferences/AddExtensionDialog.java,v 1.1 2005/01/29 03:24:51 kohnosuke Exp $
 * $Revision: 1.1 $
 * $Date: 2005/01/29 03:24:51 $
 * ============================================================================
 * ***************************************************************************/
package jp.sourceforge.jeextension.styleeditor.preferences;

import java.util.Map;

import jp.sourceforge.jeextension.common.plugin.DefaultDialog;
import jp.sourceforge.jeextension.styleeditor.core.EditorTools;

import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Text;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Composite;

/**
 * AddExtensionDialog
 */
class AddExtensionDialog extends DefaultDialog {
    
    /** 'Extension' Label. */
    private Label fLabelExt;
    
    /** return values reference when dialog was disposed. */
    private String[] fExtContainer;
    
    /** Extension's Text. */
    private Text fTextExt;
    
    /** current editting extension. */
    private String fExtension;
    
    /**
     * Initiate AddExtensionDialog Window.
     * @param shell     shell using on parent window
     * @param container dialog values container.
     */
    AddExtensionDialog(Shell shell, String[] container) {
        super(shell);
        this.fExtension = container[0];
        this.fExtContainer = container;
    }
    
    /**
     * @see org.eclipse.swt.widgets.Listener#handleEvent(org.eclipse.swt.widgets.Event)
     */
    public void handleEvent(Event event) {
    }

    /**
     * {@inheritDoc}
     * @see org.eclipse.jface.dialogs.Dialog#createDialogArea(org.eclipse.swt.widgets.Composite)
     */
    protected Control createDialogArea(Composite parent) {
        
        final Composite composite = (Composite) super.createDialogArea(parent);
        final GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 2;
        composite.setLayout(gridLayout);
        
        fLabelExt = new Label(composite, SWT.NONE);
        fLabelExt.setText(getMessage("pref.extension.dlg.label"));
        
        fTextExt = new Text(composite, SWT.BORDER);
        fTextExt.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
        
        if (fExtension != null) {
            fTextExt.setText(fExtension);
        }
        
        return composite;
    }
    
    /**
     * {@inheritDoc}
     * @see org.eclipse.jface.dialogs.Dialog#okPressed()
     */
    protected void okPressed() {
        
        String newExt = fTextExt.getText();
        
        Map map = EditorTools.getPartitionEntryMap();
        Object obj = map.get(newExt);
        if (obj == null && newExt.equals("") == false) {
            // Add
            EditorTools.getPartitionEntryList(newExt, true);
            // Modify
            Object old = map.get(fExtContainer[0]);
            if (old != null) {
                // remove old entry.
                map.remove(fExtContainer[0]);
                // add new entry.
                map.put(newExt, old);
            }
        }
        
        fExtContainer[0] = newExt;
        
        super.okPressed();
    }
}
